@@ -1,11 +1,11 @@
 def identify_columns(
         header_row,
-        identifier_name='',
+        identifier_name=None,
         country_code_name='ga:countryIsoCode',
         value_name=None,  # Value assumed to be last
         **extra_columns
 ):
-    """Optional call: Get index of relevant columns in each GA row.
+    """Find indices of relevant GA columns followed by remaining columns.
 
     Args:
         header_row (list): Column headers for the GA rows
@@ -15,15 +15,27 @@ def identify_columns(
 
     Returns:
         tuple: indexes of identifier, country and value in each GA row.
-    """
-    value_index = header_row.index(value_name) if value_name else -1
 
-    return [
-        header_row.index(identifier_name),
+    Used to reorder columns for downstream processing if more than 3 columns
+    are present in GA row data.
+    """
+    total_columns = len(header_row)
+
+    if total_columns <= 3:  # try not to break previous implementations.
+        return list(range(total_columns))
+
+    all_indices = set(range(total_columns))
+
+    relevant_indices = [
+        header_row.index(identifier_name) if identifier_name else 0,
         header_row.index(country_code_name),
-        value_index,
+        header_row.index(value_name) if value_name else total_columns - 1,
     ] + [header_row.index(column) for column in extra_columns]
 
+    remaining_indices = list(all_indices - set(relevant_indices))
+
+    return relevant_indices + remaining_indices
+
 
 def generate_row_data(results, headers=None):
     """Yield headers and data from a Google Analytics report.
@@ -35,6 +47,9 @@ def generate_row_data(results, headers=None):
     Yields:
         list: CSV-style headers and data from the report.
     """
+    if not headers:
+        headers = {}
+
     report = results.get("reports")[0]
     column_header = report.get('columnHeader', {})
 
@@ -45,11 +60,8 @@ def generate_row_data(results, headers=None):
     headers_row = column_header.get('dimensions', []).copy()
     headers_row.extend(header.get("name") for header in metric_headers)
 
-    header_indices = [i for i in range(len(headers_row))]
-
-    if headers:
-        header_indices = identify_columns(headers_row, **headers)
-        headers_row = [headers_row[i] for i in header_indices]
+    header_indices = identify_columns(headers_row, **headers)
+    headers_row = [headers_row[i] for i in header_indices]
 
     yield headers_row
 
